/* X Unicode Library ver.0.2.7
 * Copyright (c) 2000 Toshihiro Inoue
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENTSHALL
 * THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * $xunicode: xucstring.h,v 1.15.2 2000/07/07 20:54:03 Toshihiro Inoue Exp $
 */

#ifndef _XUCSTRING_H_
#define _XUCSTRING_H_

class XUCodec;

#include "xustring.h"

#include "xuobject.h"

/**
  charで格納する文字列クラス
*/

class XUCString: public XUObject
{
public:
  XUCString();
  XUCString(const XUCString& s);
  XUCString(const XUString& s);
  XUCString(const char* s);
  XUCString(int n);
  ~XUCString();
  void clear();
  void erase();
  int len() const;
  bool empty() const;
  void operator=(const XUCString& s);
  void operator=(const XUString& s);
  void operator=(const char* s);
  void operator=(int n);
  void operator+=(const XUCString& s);
  void operator+=(const char* s);
  void operator+=(char c);
  void operator-=(int l);
  XUCString operator+(const XUCString& s);
  XUCString operator+(const char* s);
  char operator[](int n);
  bool operator==(const XUCString& s) const;
  bool operator==(const char* s) const;
  bool operator!=(const XUCString& s) const;
  bool operator!=(const char* s) const;
  bool prefix(const XUCString& s) const;
  bool prefix(const char* s) const;
  bool prefix(char c) const;
  bool suffix(const XUCString& s) const;
  bool suffix(const char* s) const;
  bool suffix(char c) const;
  operator XUString() const;
  operator const char*() const;
  operator int() const;
  int find(char c, int p = 0) const;
  int findRev(char c, int p = -1) const;
  XUCString left(int l) const;
  XUCString mid(int p, int l = -1) const;
  XUCString right(int l) const;
  XUCString lower() const;
  XUCString upper() const;
  XUCString simplifySpc() const;
  void codec(XUCodec* c);
  XUCodec* codec();
  
private:
  void __init_class__();
  void init();
  void resize(int sz);
  
private:
  char* str;
  int length;
  int bufLen;
  XUCodec* mCodec;
};

#endif // _XUCSTRING_H_
